<template>
  <div class="add-common">
    <el-dialog
      :title="editCommonConfig.title + '仓库'"
      :visible.sync="editConfig.visible"
      :width="dialogWidth"
      :before-close="handleClose"
    >
      <!-- 头 -->
      <div slot="title" class="dialog-header">
        <span>{{ editCommonConfig.title + "仓库" }}</span>
        <div class="header_btns">
          <span class="btn">
            <i class="el-icon-printer"></i>
            <span>打印</span>
          </span>
          <span class="btn" style="margin-left: 15px">
            <el-button plain size="mini" style="margin-left: 15px" @click="deleteClick">删除</el-button>
          </span>
          <el-button v-if="showEdit" plain size="mini" style="margin-left: 15px" @click="editClick">编辑</el-button>
        </div>
      </div>
      <!-- 内容 -->
      <el-form
        ref="form"
        :model="editConfig.infomation"
        :rules="rules"
        label-position="left"
        label-width="100px"
        size="mini"
        style="height: 60vh; overflow-x: hidden"
      >
        <div>
          <!-- <div>aaa</div> -->
          <FormBtnsView :showWarehouse="true" @productClick="productClick" />
        </div>
        <div class="basic-info">
          <div class="basic-info-view">

            <el-row>
              <el-col :span="24" class="line_height_30px">
                <el-form-item label="仓库" prop="name">
                  <el-input
                  :disabled="showEdit"
                    v-model="editConfig.infomation.name"
                    placeholder="请输入"
                  ></el-input>
                </el-form-item>
              </el-col>
              <el-col :span="11">
                <el-form-item label="缩写" prop="code">
                  <el-input
                  :disabled="showEdit"
                    v-model="editConfig.infomation.code"
                    placeholder="请输入"
                  ></el-input>
                </el-form-item>
              </el-col>
              <el-col :span="2">&nbsp;</el-col>
              <el-col :span="11">
                <el-form-item label="地址" prop="address">
                  <el-input
                  :disabled="showEdit"
                    v-model="editConfig.infomation.address"
                    placeholder="请输入"
                  ></el-input>
                </el-form-item>
              </el-col>
            </el-row>
          </div>
          <div class="bottom">
            <el-tabs v-model="activeName" type="card">
              <el-tab-pane label="仓库配置" name="first">
                <div class="second-label">运输</div>
                <el-form-item label="入向运输" prop="inboundTransportation">
                  <el-radio-group
                  :disabled="showEdit"
                  v-model="editConfig.infomation.inboundTransportation"
                  >
                    <el-radio style="width:100%;" class="line_height_30px"
                     v-for="(item) in inboundTransportationList" 
                     :key='item.id'
                     :disabled="item.disabled"
                     :label="item.id"
                      >{{item.name}}</el-radio>
                  </el-radio-group>
                </el-form-item>
                <el-form-item label="出库运输" prop="outboundTransportation">
                  <el-radio-group
                  :disabled="showEdit"
                  v-model="editConfig.infomation.outboundTransportation"
                  >
                    <el-radio style="width:100%;" class="line_height_30px" 
                    v-for="(item) in outboundTransportationList"
                     :key='item.id'
                     :disabled="item.disabled" 
                     :label="item.id"
                     >{{item.name}}</el-radio>
                  </el-radio-group>
                </el-form-item>
              </el-tab-pane>
            </el-tabs>
          </div>
        </div>
      </el-form>
      <!-- 尾 -->
      <div v-if="showFooter" slot="footer" class="dialog-footer">
        <el-button size="small" @click="editConfig.visible = false">取消</el-button>
        <el-button type="primary" size="small" @click="saveClick('form')">保存</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { addWarehouse,updateWarehouse,deleteWarehouse } from "@/api/warehouseManage/warehouse"
import { getDataByType } from "@/api/data";
export default {
  name: "AddScrapDialog",
  props: {
    editCommonConfig: {
      type: Object,
      default: () => {
        return {
          visible: false,
          title: "新建",
          infomation: {}
        }
      }
    }
  },
  components: {},
  computed: {},
  data() {
    return {
      activeName:'first',
      dialogWidth: "50%",
      editConfig: this.editCommonConfig,
      rules: {
        name: [{ required: true, message: "请输入", trigger: "change" }],
        code: [{ required: true, message: "请输入", trigger: "change" }],
      },
      memberOptions: [],
      paymentTypeListOptions: [],
      showEdit: false, // 是否显示编辑按钮
      showFooter: false, // 是否显示取消保存
      currentState: "todo", // 当前状态
      inboundTransportationList:getDataByType('inboundTransportation'),
      outboundTransportationList:getDataByType('outboundTransportation'),
    }
  },
  created() {
    this.setBottonView()
  },
  methods: {
    // 路线
    productClick() {
      
    },
    // 设置删除/打印/编辑是否显示
    setBottonView() {
      if (this.editConfig.title === "新建") {
        this.showEdit = false
        this.showFooter = true
      } else if (this.editConfig.infomation.status === "完成") {
        this.showEdit = false
        this.showFooter = false
      } else {
        this.showEdit = true
        this.showFooter = false
      }
    },
    // 关闭
    handleClose() {
      this.editConfig.visible = false
    },
    // 刪除
    deleteClick() {
      let data = JSON.parse(JSON.stringify(this.editConfig.infomation));
      deleteWarehouse({ id: data.id }).then((res) => {
        if (res.code === 200) {
          this.editConfig.visible = false;
          this.$message.success("刪除成功!");
          this.$emit("refresh");
        }else {
                    this.$message.warning(res.msg?res.msg:"刪除失败!")
                }
      });
    },
    // 编辑
    editClick() {
      this.showEdit = false
      this.showFooter = true
    },
    saveParams() {
      let data =JSON.parse(JSON.stringify(this.editConfig.infomation));
      
      let params = {
        address:data.address,
        buyToResupply:data.buyToResupply,
        code:data.code,
        name:data.name,
        inboundTransportation:data.inboundTransportation,
        outboundTransportation:data.outboundTransportation,
      }
      if(data.id){
        params.id=data.id
      }
      return params;
    },
    // 保存
    saveClick(formName) {
      this.$refs[formName].validate((valid) => {
        if (valid) {
          const params = this.saveParams();
            if (this.editConfig.title === "新建") {
              addWarehouse(params).then((res) => {
                if (res.code === 200) {
                  this.editConfig.visible = false;
                  this.$message.success("添加成功!");
                  this.$emit('refresh')
                }else {
                    this.$message.warning(res.msg?res.msg:"添加失败!")
                }
              });
            } else {
              updateWarehouse(params).then((res) => {
                if (res.code === 200) {
                  this.editConfig.visible = false;
                  this.$message.success("编辑成功!");
                  this.$emit('refresh')
                }else {
                    this.$message.warning(res.msg?res.msg:"编辑失败!")
                }
              });
            }
        }else {
          console.log("error submit");
          return false;
        }
      });
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
.dialog-header {
  display: flex;
  align-items: center;
  font-size: 14px;
  color: #333;
  .header_btns {
    margin-left: auto;
    margin-right: 60px;
    .btn {
      cursor: no-drop;
    }
  }
}
.content-status {
  display: flex;
}
.basic-info {
  height: calc(100% - 80px);
  overflow: auto;
  margin: 20px;
  border: 1px solid #dcdfe6;
  box-shadow: inset 0 0 2px #dee2e6;
  -moz-box-shadow: inset 0 0 2px #dee2e6;
  -webkit-box-shadow: inset 0 0 2px #dee2e6;
  .basic-info-view {
    margin-top: 20px;
    padding:0 20px;

  }
  .bottom{
    .second-label {
      border-bottom: 1px solid #d9d9d9;
      margin-bottom: 10px;
    }
    ::v-deep .el-tabs__content{
      padding: 0 20px;
    }
  }
  
}
.purchase-view {
  display: flex;
  .left {
    width: 50%;
  }
  .right {
    width: 50%;
  }
}

::v-deep {
  .el-dialog__headerbtn {
    position: absolute;
    top: 18px;
  }
  .el-button {
    &:hover {
      border: 1px solid #dcdfe6;
      color: #333;
    }
  }
  .el-tabs--card > .el-tabs__header .el-tabs__nav {
    margin-left: 20px;
  }
  .el-tabs__item {
    height: 30px;
    line-height: 30px;
    font-size: 13px;
  }
}
</style>
